#
# download_sources() - If the source code has not been downloaded and we have
# a sources file, try to fetch the source.  If the source is downloaded and
# can be verified, do that and exit.
#
# Parameters:   $1    The name of the sources file.
#

download_sources() {
   # find a suitable download tool
   if [ -x `which wget` ]
   then
      DWNLDTOOL="`which wget`"
   elif [ -x `which lynx` ]
   then
      DWNLDTOOL="`which lynx` -source"
   else
      echo
      echo "You lack a sufficient download tool for protopkg.  Make sure"
      echo "that either wget or lynx is installed, both of which are in"
      echo "Slackware in the networking series."
      echo
      exit
   fi

   # let's do it
   cat $1 | read_rules "sources" | (
      while read Surl Smd5
      do
         Sfile="`basename $Surl`"
         GOOD="n"

         # do we have the file already?
         if [ -f $Sfile ]
         then
            # we have the file, does it check out?
            if [ ! "$Smd5" = "" ]
            then
               oldSum="`md5sum $Sfile`"
               oldSum="`echo $oldSum | cut -d ' ' -f 1`"

               if [ "$oldSum" = "$Smd5" ]
               then
                  GOOD="y"
               else
                  GOOD="n"
               fi
            else
               # we can't verify the MD5 sig, assume good
               GOOD="y"
            fi
         fi

         # let's fetch
         if [ "$GOOD" = "n" ]
         then
            $DWNLDTOOL $Surl

            if [ ! "$Smd5" = "" ]
            then
               # verify the MD5 sig
               newSum="`md5sum $Sfile`"
               newSum="`echo $newSum | cut -d ' ' -f 1`"

               if [ ! "$newSum" = "$Smd5" ]
               then
                  echo "$Sfile is invalid!"
                  mv $Sfile $Sfile.invalid
               fi
            fi
         fi
      done )

   unset Surl Smd5 Sfile GOOD
}
